==> auto-ui-0.3.10.tgz: package/es/input/index.js <==
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) if (e.indexOf(p[i]) < 0)
            t[p[i]] = s[p[i]];
    return t;
};
import * as React from 'react';
import cn from 'classnames';
import './style.scss';
var Input = function (props) {
    var type = props.type, className = props.className, addonBefore = props.addonBefore, addonAfter = props.addonAfter, error = props.error, multi = props.multi, disabled = props.disabled, value = props.value, onChange = props.onChange, placeholder = props.placeholder, mini = props.mini, otherProps = __rest(props, ["type", "className", "addonBefore", "addonAfter", "error", "multi", "disabled", "value", "onChange", "placeholder", "mini"]);
    var composeClassName = cn('x-input', {
        'x-input--error': error,
        'x-input--multi': multi,
        'x-input--disabled': disabled,
        'x-input--mini': mini,
    }, className);
    if (multi) {
        return (React.createElement("div", __assign({}, otherProps, { className: composeClassName }),
            !!addonBefore && React.createElement("div", { className: "x-input__addon-before" }, addonBefore),
            React.createElement("textarea", { disabled: disabled, className: "x-input__ipt", value: value, placeholder: placeholder, onChange: onChange }),
            !!addonAfter && React.createElement("div", { className: "x-input__addon-after" }, addonAfter)));
    }
    return (React.createElement("div", __assign({}, otherProps, { className: composeClassName }),
        !!addonBefore && React.createElement("div", { className: "x-input__addon-before" }, addonBefore),
        React.createElement("input", { disabled: disabled, className: "x-input__ipt", value: value, placeholder: placeholder, onChange: onChange, type: type || 'text' }),
        !!addonAfter && React.createElement("div", { className: "x-input__addon-after" }, addonAfter)));
};
export default Input;

==> auto-ui-0.3.11.tgz: package/es/input/index.js <==
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) if (e.indexOf(p[i]) < 0)
            t[p[i]] = s[p[i]];
    return t;
};
import * as React from 'react';
import cn from 'classnames';
import './style.scss';
var Input = function (props) {
    var type = props.type, className = props.className, addonBefore = props.addonBefore, addonAfter = props.addonAfter, error = props.error, multi = props.multi, disabled = props.disabled, value = props.value, onChange = props.onChange, placeholder = props.placeholder, mini = props.mini, inputProps = props.inputProps, otherProps = __rest(props, ["type", "className", "addonBefore", "addonAfter", "error", "multi", "disabled", "value", "onChange", "placeholder", "mini", "inputProps"]);
    var composeClassName = cn('x-input', {
        'x-input--error': error,
        'x-input--multi': multi,
        'x-input--disabled': disabled,
        'x-input--mini': mini,
    }, className);
    if (multi) {
        return (React.createElement("div", __assign({}, otherProps, { className: composeClassName }),
            !!addonBefore && React.createElement("div", { className: "x-input__addon-before" }, addonBefore),
            React.createElement("textarea", { disabled: disabled, className: "x-input__ipt", value: value, placeholder: placeholder, onChange: onChange }),
            !!addonAfter && React.createElement("div", { className: "x-input__addon-after" }, addonAfter)));
    }
    return (React.createElement("div", __assign({}, otherProps, { className: composeClassName }),
        !!addonBefore && React.createElement("div", { className: "x-input__addon-before" }, addonBefore),
        React.createElement("input", __assign({ disabled: disabled, className: "x-input__ipt", value: value, placeholder: placeholder, onChange: onChange, type: type || 'text' }, inputProps)),
        !!addonAfter && React.createElement("div", { className: "x-input__addon-after" }, addonAfter)));
};
export default Input;
